@@ -8,9 +8,12 @@ from lesscode_utils.common_utils import fill
 
 
 def date_time_add(date_time: Union[date, datetime], seconds: int = 0, minutes: int = 0, hours: int = 0, days: int = 0,
-                  months: int = 0, years: int = 0, is_format=False, template="%Y-%m-%d %H:%M:%S"):
+                  months: int = 0, years: int = 0, weeks: int = 0, microseconds: int = 0, is_format=False,
+                  template="%Y-%m-%d %H:%M:%S"):
     """
         时间偏移，可以正向偏移或者负向偏移，值大于0为正向偏移，值小于0为负向偏移
+    :param microseconds:
+    :param weeks: 周数
     :param date_time: 时间格式的时间
     :param seconds: 秒数
     :param minutes: 分钟数
@@ -26,29 +29,18 @@ def date_time_add(date_time: Union[date, datetime], seconds: int = 0, minutes: i
         raise Exception(f"date_time type = {type(date_time)} is error")
     date_time = date_time if isinstance(date_time, datetime) else datetime(year=date_time.year, month=date_time.month,
                                                                            day=date_time.day)
-    date_time = date_time + timedelta(seconds=seconds, minutes=minutes, hours=hours, days=days)
-    final_year = date_time.year
-    final_month = date_time.month
-    if months:
-        _final_month = date_time.month + months % 12
-        _final_year = date_time.year + years + months // 12
-        if _final_month > 12:
-            final_month = _final_month % 12
-            final_year += _final_month // 12
-        elif _final_month < 0:
-            final_month = _final_month % 12
-            final_year -= _final_month // 12
-        else:
-            final_year = _final_year
-            final_month = _final_month
-    date_time = datetime(year=final_year, month=final_month, day=date_time.day,
-                         hour=date_time.hour,
-                         minute=date_time.minute, second=date_time.second)
+    try:
+        relativedelta = importlib.import_module("dateutil.relativedelta")
+    except ImportError:
+        raise Exception(f"python-dateutil is not exist,run:pip install python-dateutil")
+    new_datetime = date_time + relativedelta.relativedelta(years=years, months=months, days=days, hours=hours,
+                                                           minutes=minutes, seconds=seconds, weeks=weeks,
+                                                           microseconds=microseconds)
     if is_format:
-        date_str = date_time.strftime(template)
+        date_str = new_datetime.strftime(template)
         return date_str
     else:
-        return date_time
+        return new_datetime
 
 
 def date_time_diff(date_time1: datetime, date_time2: datetime, return_type: str = None,
@@ -848,3 +840,12 @@ class SuperDateTime:
         start_date = datetime(new_year, new_month, 1)
         return [self._format_datetime(start_date, data_type=data_type, datetime_format=datetime_format),
                 self._format_datetime(end_date, data_type=data_type, datetime_format=datetime_format)]
+
+    def offset(self, seconds: int = 0, minutes: int = 0, hours: int = 0, days: int = 0,
+               months: int = 0, years: int = 0, weeks: int = 0, microseconds: int = 0, data_type: str = "datetime",
+               datetime_format: str = "%Y-%m-%d %H:%M:%S"):
+
+        return self._format_datetime(
+            date_time_add(self.value, seconds=seconds, minutes=minutes, hours=hours, days=days, months=months,
+                          years=years, weeks=weeks, microseconds=microseconds,
+                          is_format=False), data_type=data_type, datetime_format=datetime_format)
